@@ -7,6 +7,5 @@ class LowerfenceValidator(_plotly_utils.basevalidators.DataArrayValidator):
             plotly_name=plotly_name,
             parent_name=parent_name,
             edit_type=kwargs.pop("edit_type", "calc"),
-            role=kwargs.pop("role", "data"),
-            **kwargs
+            **kwargs,
         )
