@@ -9,7 +9,6 @@ class TicklabelpositionValidator(_plotly_utils.basevalidators.EnumeratedValidato
             plotly_name=plotly_name,
             parent_name=parent_name,
             edit_type=kwargs.pop("edit_type", "colorbars"),
-            role=kwargs.pop("role", "info"),
             values=kwargs.pop(
                 "values",
                 [
@@ -17,9 +16,13 @@ class TicklabelpositionValidator(_plotly_utils.basevalidators.EnumeratedValidato
                     "inside",
                     "outside top",
                     "inside top",
+                    "outside left",
+                    "inside left",
+                    "outside right",
+                    "inside right",
                     "outside bottom",
                     "inside bottom",
                 ],
             ),
-            **kwargs
+            **kwargs,
         )
