@@ -10,6 +10,5 @@ class TicklenValidator(_plotly_utils.basevalidators.NumberValidator):
             parent_name=parent_name,
             edit_type=kwargs.pop("edit_type", "colorbars"),
             min=kwargs.pop("min", 0),
-            role=kwargs.pop("role", "style"),
-            **kwargs
+            **kwargs,
         )
