@@ -7,7 +7,6 @@ class DirectionValidator(_plotly_utils.basevalidators.EnumeratedValidator):
             plotly_name=plotly_name,
             parent_name=parent_name,
             edit_type=kwargs.pop("edit_type", "calc"),
-            role=kwargs.pop("role", "style"),
             values=kwargs.pop("values", ["clockwise", "counterclockwise"]),
-            **kwargs
+            **kwargs,
         )
