@@ -6,13 +6,12 @@ class MinexponentValidator(_plotly_utils.basevalidators.NumberValidator):
         self,
         plotly_name="minexponent",
         parent_name="scattercarpet.marker.colorbar",
-        **kwargs
+        **kwargs,
     ):
         super(MinexponentValidator, self).__init__(
             plotly_name=plotly_name,
             parent_name=parent_name,
             edit_type=kwargs.pop("edit_type", "colorbars"),
             min=kwargs.pop("min", 0),
-            role=kwargs.pop("role", "style"),
-            **kwargs
+            **kwargs,
         )
