@@ -7,6 +7,5 @@ class YperiodValidator(_plotly_utils.basevalidators.AnyValidator):
             plotly_name=plotly_name,
             parent_name=parent_name,
             edit_type=kwargs.pop("edit_type", "calc"),
-            role=kwargs.pop("role", "info"),
-            **kwargs
+            **kwargs,
         )
